import { type ISession } from 'myst-cli-utils';
import type { DownloadResult, Fetcher, ResolutionOptions } from './types.js';
export declare function normalizePMID(session: ISession, pmid: string): string;
/**
 * Convert a single PMID to PMCID
 *
 * Returns PMCID
 *
 * https://www.ncbi.nlm.nih.gov/pmc/tools/id-converter-api/
 */
export declare function convertPMID2PMCID(session: ISession, pmid: string, opts?: ResolutionOptions): Promise<string | undefined>;
/**
 * Convert multiple PMIDs to PMCIDs
 *
 * Returns a PMID:PMCID lookup dictionary for successful conversions
 *
 * https://www.ncbi.nlm.nih.gov/pmc/tools/id-converter-api/
 */
export declare function convertPMIDs2PMCIDs(session: ISession, pmids: string[], opts?: ResolutionOptions): Promise<Record<string, string> | undefined>;
/**
 * Query NIH APIs for single DOI from PubMed ID
 */
export declare function convertPMID2DOI(session: ISession, pmid: string, opts?: ResolutionOptions): Promise<string | undefined>;
/**
 * Query NIH APIs for multiple DOIs from PubMed IDs
 */
export declare function convertPMIDs2DOIs(session: ISession, pmids: string[], opts?: ResolutionOptions): Promise<Record<string, string | null> | undefined>;
/**
 * Construct JATS download url from PubMed Central ID
 *
 * This url uses the efetch utility from NIH.
 *
 * If a DOI is provided, this will attempt to resolve the DOI to a PMCID
 */
export declare function constructJatsUrlFromPubMedCentral(session: ISession, urlOrDoi: string, opts: ResolutionOptions): Promise<string | undefined>;
/**
 * Download JATS from Open-Access NIH S3 bucket, if available
 */
export declare function getPubMedJatsFromS3(session: ISession, pmcid: string): Promise<DownloadResult>;
/**
 * Return listings file path
 *
 * If file does not exist, it will be downloaded.
 */
export declare function getListingsFile(session: ISession, dest?: string, fetcher?: Fetcher): Promise<string>;
export declare function getDataFromPMC(session: ISession, pmcid: string, outputDir: string, listing?: string, fetcher?: Fetcher): Promise<void>;
export declare function getPubMedJatsFromData(session: ISession, pmcid: string, outputDir: string, listing?: string, fetcher?: Fetcher): Promise<DownloadResult>;
//# sourceMappingURL=pubmed.d.ts.map